@@ -28,6 +28,8 @@ class BaseClient(ABC):
 
     COIN_MARGINED_API_VERSION = "v1"
 
+    USD_MARGINED_API_VERSION = "v1"
+
     # ACCOUNT_TYPE
     SPOT = "spot"   # 现货
     OTC = "otc"
@@ -104,6 +106,10 @@ class BaseClient(ABC):
     def _create_coin_margined_api_uri(self, path: str, version: str = COIN_MARGINED_API_VERSION) -> str:
         return f"{self.API_FUTURE_URL}/swap-api/{version}/{path}"
 
+    # U本位合约
+    def _create_usd_margined_api_uri(self, path: str, version: str = USD_MARGINED_API_VERSION) -> str:
+        return f"{self.API_FUTURE_URL}/linear-swap-api/{version}/{path}"
+
     @staticmethod
     def _get_headers() -> Dict:
         return {'Content-type': 'application/x-www-form-urlencoded', 'Accept': 'application/json'}
@@ -207,6 +213,11 @@ class AsyncClient(BaseClient):
         uri = self._create_spot_account_api_uri(path, version)
         return await self._request(method, uri, params, data, True)
 
+    async def _request_spot_order_api(self, method="get", path=None, version=BaseClient.SPOT_API_VERSION,
+                                      params=None, data=None):
+        uri = self._create_spot_order_api_uri(path, version)
+        return await self._request(method, uri, params, data, True)
+
     async def _request_future_private_api(self, method="get", path=None, version=BaseClient.SPOT_API_VERSION,
                                         params=None, data=None):
         uri = self._create_future_api_uri(path, version)
@@ -217,6 +228,12 @@ class AsyncClient(BaseClient):
         uri = self._create_coin_margined_api_uri(path, version)
         return await self._request(method, uri, params, data, True)
 
+    async def _request_usd_margined_private_api(
+            self, method="get", path=None, version=BaseClient.USD_MARGINED_API_VERSION, params=None, data=None
+    ):
+        uri = self._create_usd_margined_api_uri(path, version)
+        return await self._request(method, uri, params, data, True)
+
     async def spot_system_status(self):
         """
         获取当前系统状态
@@ -338,6 +355,10 @@ class AsyncClient(BaseClient):
             params={'accountType': account_type, "valuationCurrency": currency}
         )
 
+    async def spot_cancel_order(self, order_id):
+        uri = self._create_spot_order_api_uri(f"orders/{order_id}/submitcancel")
+        return await self._request_spot_order_api("post", uri)
+
     async def future_transfer(self, currency: str, amount, transfer_type: str):
         """
         币币现货账户与交割合约账户划转
@@ -1193,6 +1214,17 @@ class AsyncClient(BaseClient):
         data = package_data(remove_key(locals()))
         return await self._request_coin_margined_private_api("post", "swap_lightning_close_position", data=data)
 
+    #### U本位永续合约交易接口 #####
+
+    async def usd_margined_cancel_order(self, contract_code, order_id=None, client_order_id=None, cross=True):
+        """
+        【全仓】撤销订单
+        """
+        data = package_data(remove_key(locals(), "self,cross"))
+        return await self._request_usd_margined_private_api(
+            "post", "swap_cross_cancel" if cross else "swap_cancel", data=data
+        )
+
 
 
 
